
global START_TEST_COMMAND, TEST_STEP_COMMAND, END_TEST_COMMAND,START_STEP_COMMAND, END_STEP_COMMAND, ASSERT_COMMAND,\
    executionReportUrl

START_TEST_COMMAND = 'mobile:test:start'
TEST_STEP_COMMAND = "mobile:test:step"
START_STEP_COMMAND = 'mobile:step:start'
END_STEP_COMMAND = "mobile:step:end"
END_TEST_COMMAND = "mobile:test:end"
ASSERT_COMMAND = "mobile:status:assert"

executionReportUrl = 'testGridReportUrl'